=======
History
=======

1.3.4 (2020-10-01)
------------------

* Add language to profile dict
* Correctly handle deleted users

1.3.3 (2020-09-30)
------------------

* Added ability to save screenshots of badoo profile pages
* Added ability to save badoo user profile images
* Online status now returned in profile dict


0.1.0 (2020-09-26)
------------------

* First release on PyPI.
